@@ -1,4 +1,3 @@
-{-# LANGUAGE CPP #-}
 {-# LANGUAGE DeriveDataTypeable #-}
 {-# LANGUAGE DeriveGeneric #-}
 {-# LANGUAGE MultiParamTypeClasses #-}
@@ -17,24 +16,14 @@ module Numeric.Log.Signed
 ( SignedLog(..)
 ) where
 
-#if __GLASGOW_HASKELL__ < 710
-import Data.Monoid (Monoid(..))
-#endif
 import Data.Data (Data(..))
 import GHC.Generics (Generic(..))
-import Data.Typeable (Typeable)
 import Numeric
 import Text.Read as T
 import Text.Show as T
-#if __GLASGOW_HASKELL__ < 710
-import Data.Functor ((<$>))
-#endif
-
--- $setup
--- >>> let SLExp sX x ~= SLExp sY y = abs ((exp x-(multSign (nxor sX sY) (exp y))) / exp x) < 0.01
 
 -- | @Log@-domain @Float@ and @Double@ values, with a sign bit.
-data SignedLog a = SLExp { signSL :: Bool, lnSL :: a} deriving (Data, Typeable, Generic)
+data SignedLog a = SLExp { signSL :: Bool, lnSL :: a} deriving (Data, Generic)
 
 negInf :: Fractional a => a
 negInf = (-1)/0
@@ -84,6 +73,13 @@ nxor = (==)
 
 -- $SignedLogNumTests
 --
+-- Repeating internals, add testing function (~=)
+--
+-- >>> let nxor = (==)
+-- >>> let multSign b = if b then id else (*) (-1)
+--
+-- >>> let SLExp sX x ~= SLExp sY y = abs ((exp x-(multSign (nxor sX sY) (exp y))) / exp x) < 0.01
+--
 -- Subtraction
 --
 -- >>> (3 - 1 :: SignedLog Double) ~= 2
